@@ -3,4 +3,4 @@ from excelbird.styles import *
 from excelbird.schema import *
 from excelbird.exceptions import *
 from excelbird._layout_references import *
-from excelbird._base import Style
+from excelbird._base.dotdict import *
